<?php
namespace KudosQodef\Modules\Shortcodes\Blockquote;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;
/**
 * Class Blockquote
 */
class Blockquote implements ShortcodeInterface {

	/**
	 * @var string
	 */
	private $base;

	public function __construct() {
		$this->base = 'qodef_blockquote';

		add_action('vc_before_init', array($this, 'vcMap'));
	}

	/**
	 * Returns base for shortcode
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}

	/**
	 * Maps shortcode to Visual Composer. Hooked on vc_before_init
	 *
	 * @see qode_core_get_carousel_slider_array_vc()
	 */
	public function vcMap() {

		vc_map( array(
				'name' => esc_html__('Select Blockquote', 'kudos'),
				'base' => $this->getBase(),
				'category' => 'by SELECT',
				'icon' => 'icon-wpb-blockquote extended-custom-icon',
				'allowed_container_element' => 'vc_row',
				'params' => array(
					array(
						"type" => "textarea",
						"heading" => esc_html__("Text", 'kudos'),
						"param_name" => "text",
						"value" => "Blockquote text",
						"save_always" => true
					),
					array(
						"type" => "dropdown",
						"heading" => esc_html__("Title tag", 'kudos'),
						"param_name" => "title_tag",
						"value" => array(
							""   => "",
							esc_html__("h2", 'kudos') => "h2",
							esc_html__("h3", 'kudos') => "h3",
							esc_html__("h4", 'kudos') => "h4",
							esc_html__("h5", 'kudos') => "h5",
							esc_html__("h6", 'kudos') => "h6",
						),
						"description" => ""
					),
                    array(
                        "type" => "textfield",
                        "heading" => esc_html__("Font Size (px)", 'kudos'),
                        "param_name" => "font_size"
                    ),
					array(
						"type" => "textfield",
						"heading" => esc_html__("Width (%)", 'kudos'),
						"param_name" => "width"
					)
				)
		) );

	}

	/**
	 * Renders shortcodes HTML
	 *
	 * @param $atts array of shortcode params
	 * @return string
	 */
	public function render($atts, $content = null) {

		$args = array(
			'text' => '',
			'title_tag' => 'h5',
			'width' => '',
			'font_size' => ''
		);

		$params = shortcode_atts($args, $atts);

		$params['blockquote_style'] = $this->getBlockquoteStyle($params);
		$params['blockquote_title_tag'] = $this->getBlockquoteTitleTag($params,$args);
        $params['blockquote_title_style'] = $this->getBlockquoteTitleStyle($params);

		//Get HTML from template
		$html = kudos_qodef_get_shortcode_module_template_part('templates/blockquote-template', 'blockquote', '', $params);

		return $html;

	}

	/**
	 * Return Style for Blockquote
	 *
	 * @param $params
	 * @return string
	 */
	private function getBlockquoteStyle($params) {
		$blockquote_style = array();

		if ($params['width'] !== '') {
			$width = strstr($params['width'], '%') ? $params['width'] : $params['width'].'%';
			$blockquote_style[] = 'width: '.$width;
		}

		return implode(';', $blockquote_style);
	}

	/**
	 * Return Blockquote Title Tag. If provided heading isn't valid get the default one
	 *
	 * @param $params
	 * @return string
	 */
	private function getBlockquoteTitleTag($params,$args) {
		$headings_array = array('h2', 'h3', 'h4', 'h5', 'h6');
		return (in_array($params['title_tag'], $headings_array)) ? $params['title_tag'] : $args['title_tag'];
	}

    /**
     * Return Style for Title
     *
     * @param $params
     * @return string
     */
    private function getBlockquoteTitleStyle($params) {
        $blockquote_title_style = array();

        if ($params['font_size'] !== '') {
            $blockquote_title_style[] = 'font-size: ' . $params['font_size'] . 'px';
        }

        return implode(';', $blockquote_title_style);
    }
}