<?php

namespace KudosQodef\Modules\Shortcodes\BlogList;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;
/**
 * Class BlogList
 */
class BlogList implements ShortcodeInterface {
	/**
	* @var string
	*/
	private $base;
	
	function __construct() {
		$this->base = 'qodef_blog_list';
		
		add_action('vc_before_init', array($this,'vcMap'));

		//Category filter
		add_filter( 'vc_autocomplete_qodef_blog_list_category_callback', array( &$this, 'blogListCategoryAutocompleteSuggester', ), 10, 1 ); // Get suggestion(find). Must return an array

		//Category render
		add_filter( 'vc_autocomplete_qodef_blog_list_category_render', array( &$this, 'blogListCategoryAutocompleteRender', ), 10, 1 ); // Get suggestion(find). Must return an array

	}
	
	public function getBase() {
		return $this->base;
	}
	public function vcMap() {

		vc_map( array(
			'name' => esc_html__('Select Blog List', 'kudos'),
			'base' => $this->base,
			'icon' => 'icon-wpb-blog-list extended-custom-icon',
			'category' => 'by SELECT',
			'allowed_container_element' => 'vc_row',
			'params' => array(
					array(
						'type' => 'dropdown',
						'holder' => 'div',
						'class' => '',
						'heading' => esc_html__('Type', 'kudos'),
						'param_name' => 'type',
						'value' => array(
							esc_html__('Boxes', 'kudos') => 'boxes',
							esc_html__('Masonry', 'kudos') => 'masonry',
							esc_html__('Minimal', 'kudos') => 'minimal',
							esc_html__('Image in box', 'kudos') => 'image_in_box'
						),
						'description' => '',
                        'save_always' => true
					),
					array(
						'type' => 'textfield',
						'holder' => 'div',
						'class' => '',
						'heading' => esc_html__('Number of Posts', 'kudos'),
						'param_name' => 'number_of_posts',
						'description' => ''
					),
					array(
						'type' => 'dropdown',
						'holder' => 'div',
						'class' => '',
						'heading' => esc_html__('Number of Columns', 'kudos'),
						'param_name' => 'number_of_columns',
						'value' => array(
							esc_html__('One', 'kudos') => '1',
							esc_html__('Two', 'kudos') => '2',
							esc_html__('Three', 'kudos') => '3',
							esc_html__('Four', 'kudos') => '4'
						),
						'description' => '',
						'dependency' => Array('element' => 'type', 'value' => array('boxes')),
                        'save_always' => true
					),
					array(
						'type' => 'dropdown',
						'holder' => 'div',
						'class' => '',
						'heading' => esc_html__('Order By', 'kudos'),
						'param_name' => 'order_by',
						'value' => array(
							esc_html__('Title', 'kudos') => 'title',
							esc_html__('Date', 'kudos') => 'date'
						),
						'save_always' => true,
						'description' => ''
					),
					array(
						'type' => 'dropdown',
						'holder' => 'div',
						'class' => '',
						'heading' => esc_html__('Order', 'kudos'),
						'param_name' => 'order',
						'value' => array(
							esc_html__('ASC', 'kudos') => 'ASC',
							esc_html__('DESC', 'kudos') => 'DESC'
						),
						'save_always' => true,
						'description' => ''
					),
					array(
						'type' => 'autocomplete',
						'heading' => esc_html__('Category Slug', 'kudos'),
						'param_name' => 'category',
						'description' => esc_html__('Leave empty for all or use comma for list', 'kudos'),
						'admin_label' => true
					),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Image', 'kudos'),
                        'param_name' => 'show_image',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
                    array(
                        'type' => 'dropdown',
                        'holder' => 'div',
                        'class' => '',
                        'heading' => esc_html__('Image Size', 'kudos'),
                        'param_name' => 'image_size',
                        'value' => array(
                            esc_html__('Original', 'kudos') => 'original',
                            esc_html__('Landscape', 'kudos') => 'landscape',
                            esc_html__('Square', 'kudos') => 'square'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'show_image', 'value' => array('yes')),
                        'save_always' => true,
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
					array(
						'type' => 'textfield',
						'holder' => 'div',
						'class' => '',
						'heading' => esc_html__('Text length', 'kudos'),
						'param_name' => 'text_length',
						'description' => esc_html__('Number of characters', 'kudos')
					),
					array(
						'type' => 'dropdown',
						'class' => '',
						'heading' => esc_html__('Title Tag', 'kudos'),
						'param_name' => 'title_tag',
						'value' => array(
							''   => '',
							esc_html__('h2', 'kudos') => 'h2',
							esc_html__('h3', 'kudos') => 'h3',
							esc_html__('h4', 'kudos') => 'h4',
							esc_html__('h5', 'kudos') => 'h5',
							esc_html__('h6', 'kudos') => 'h6',
						),
						'description' => ''
					),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Date', 'kudos'),
                        'param_name' => 'show_date',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes', 'masonry', 'image_in_box', 'minimal')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Category', 'kudos'),
                        'param_name' => 'show_category',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes', 'masonry', 'image_in_box')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Author', 'kudos'),
                        'param_name' => 'show_author',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes', 'masonry', 'image_in_box')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Share', 'kudos'),
                        'param_name' => 'show_share',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes', 'masonry', 'image_in_box')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Comments', 'kudos'),
                        'param_name' => 'show_comments',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes', 'masonry', 'image_in_box')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Likes', 'kudos'),
                        'param_name' => 'show_likes',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes', 'masonry', 'image_in_box')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Show Read More', 'kudos'),
                        'param_name' => 'show_read_more',
                        'value' => array(
                            '' => '',
                            esc_html__('Yes', 'kudos') => 'yes',
                            esc_html__('No', 'kudos') => 'no'
                        ),
                        'description' => '',
                        'dependency' => Array('element' => 'type', 'value' => array('boxes', 'masonry', 'image_in_box')),
                        'group' => esc_html__('Layout Options', 'kudos')
                    )
				)
		) );

	}
	public function render($atts, $content = null) {
		
		$default_atts = array(
			'type' => 'boxes',
            'number_of_posts' => '',
            'number_of_columns' => '',
            'show_image' => 'yes',
            'image_size' => 'original',
            'order_by' => '',
            'order' => '',
            'category' => '',
            'title_tag' => 'h5',
			'text_length' => '90',
            'show_date' => 'yes',
            'show_category' => 'yes',
            'show_author' => 'yes',
            'show_share' => 'yes',
            'show_comments' => 'yes',
            'show_likes' => 'yes',
            'show_read_more' => 'no'
        );
		
		$params = shortcode_atts($default_atts, $atts);
		extract($params);
		$params['holder_classes'] = $this->getBlogHolderClasses($params);
	
		$queryArray = $this->generateBlogQueryArray($params);
		$query_result = new \WP_Query($queryArray);
		$params['query_result'] = $query_result;
		

		$params['thumb_image_size'] = $this->generateImageSize($params);
		$params['info_bottom_class'] = $this->getInfoBottomClass($params);

		$html ='';
        $html .= kudos_qodef_get_shortcode_module_template_part('templates/blog-list-holder', 'blog-list', '', $params);
		return $html;
		
	}

	/**
	   * Generates holder classes
	   *
	   * @param $params
	   *
	   * @return string
	*/
	private function getBlogHolderClasses($params){
		$holderClasses = '';
		
		$columnNumber = $this->getColumnNumberClass($params);
		
		if(!empty($params['type'])){
			switch($params['type']){
				case 'image_in_box':
					$holderClasses = 'qodef-image-in-box';
				break;
				case 'boxes' : 
					$holderClasses = 'qodef-boxes';
				break;	
				case 'masonry' : 
					$holderClasses = 'qodef-masonry';
				break;
				case 'minimal' :
					$holderClasses = 'qodef-minimal';
				break;	
				default: 
					$holderClasses = 'qodef-boxes';
			}
		}
		
		$holderClasses .= ' '.$columnNumber;
		
		return $holderClasses;
		
	}

	/** 
	   * Generates column classes for boxes type
	   *
	   * @param $params
	   *
	   * @return string
	*/
	private function getColumnNumberClass($params){
		
		$columnsNumber = '';
		$type = $params['type'];
		$columns = $params['number_of_columns'];
		
        if ($type == 'boxes') {
            switch ($columns) {
                case 1:
                    $columnsNumber = 'qodef-one-column';
                    break;
                case 2:
                    $columnsNumber = 'qodef-two-columns';
                    break;
                case 3:
                    $columnsNumber = 'qodef-three-columns';
                    break;
                case 4:
                    $columnsNumber = 'qodef-four-columns';
                    break;
                default:
					$columnsNumber = 'qodef-one-column';
                    break;
            }
        }
		return $columnsNumber;
	}

    /**
     * Generates classes for section info bottom
     *
     * @param $params
     *
     * @return string
     */
    private function getInfoBottomClass($params){

        $class = '';

        if($params['show_author'] != 'yes' && $params['show_coments'] != 'yes' && $params['show_likes'] != 'yes') {
            $class .= 'qodef-no-info-left ';
        }
        else {
            if( kudos_qodef_options()->getOptionValue('enable_social_share') != 'yes'
                || kudos_qodef_options()->getOptionValue('enable_social_share_on_post') != 'yes'
                || $params['show_share'] != 'yes') {
                $class .= 'qodef-no-info-share ';
            }
        }

        return $class;
    }

	/**
	   * Generates query array
	   *
	   * @param $params
	   *
	   * @return array
	*/
	public function generateBlogQueryArray($params){
		
		$queryArray = array(
			'orderby' => $params['order_by'],
			'order' => $params['order'],
			'posts_per_page' => $params['number_of_posts'],
			'category_name' => $params['category']
		);
		return $queryArray;
	}

	/**
	   * Generates image size option
	   *
	   * @param $params
	   *
	   * @return string
	*/
	private function generateImageSize($params){
		$thumbImageSize = '';
		$imageSize = $params['image_size'];

        if($params['type'] == 'minimal') {
            $thumbImageSize = array('50', '50');
        } else if ($imageSize !== '' && $imageSize == 'landscape') {
            $thumbImageSize .= 'kudos_qodef_landscape';
        } else if($imageSize === 'square'){
			$thumbImageSize .= 'kudos_qodef_square';
		} else if ($imageSize !== '' && $imageSize == 'original') {
            $thumbImageSize .= 'full';
        }

		return $thumbImageSize;
	}

	/**
	 * Filter categories
	 *
	 * @param $query
	 *
	 * @return array
	 */
	public function blogListCategoryAutocompleteSuggester( $query ) {
		global $wpdb;
		$post_meta_infos = $wpdb->get_results( $wpdb->prepare( "SELECT a.slug AS slug, a.name AS category_title
					FROM {$wpdb->terms} AS a
					LEFT JOIN ( SELECT term_id, taxonomy  FROM {$wpdb->term_taxonomy} ) AS b ON b.term_id = a.term_id
					WHERE b.taxonomy = 'category' AND a.name LIKE '%%%s%%'", stripslashes( $query ) ), ARRAY_A );

		$results = array();
		if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
			foreach ( $post_meta_infos as $value ) {
				$data          = array();
				$data['value'] = $value['slug'];
				$data['label'] = ( ( strlen( $value['category_title'] ) > 0 ) ? esc_html__( 'Category', 'kudos' ) . ': ' . $value['category_title'] : '' );
				$results[]     = $data;
			}
		}

		return $results;

	}

	/**
	 * Find categories by slug
	 * @since 4.4
	 *
	 * @param $query
	 *
	 * @return bool|array
	 */
	public function blogListCategoryAutocompleteRender( $query ) {
		$query = trim( $query['value'] ); // get value from requested
		if ( ! empty( $query ) ) {
			// get category
			$category = get_term_by( 'slug', $query, 'category' );
			if ( is_object( $category ) ) {

				$category_slug = $category->slug;
				$category_title = $category->name;

				$category_title_display = '';
				if ( ! empty( $category_title ) ) {
					$category_title_display = esc_html__( 'Category', 'kudos' ) . ': ' . $category_title;
				}

				$data          = array();
				$data['value'] = $category_slug;
				$data['label'] = $category_title_display;

				return ! empty( $data ) ? $data : false;
			}

			return false;
		}

		return false;
	}
	
}
