<?php
namespace KudosQodef\Modules\Shortcodes\ElementsHolder;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;

class ElementsHolder implements ShortcodeInterface{
	private $base;
	function __construct() {
		$this->base = 'qodef_elements_holder';
		add_action('vc_before_init', array($this, 'vcMap'));
	}
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		vc_map( array(
			'name' => esc_html__('Select Elements Holder', 'kudos'),
			'base' => $this->base,
			'icon' => 'icon-wpb-elements-holder extended-custom-icon',
			'category' => 'by SELECT',
			'as_parent' => array('only' => 'qodef_elements_holder_item'),
			'js_view' => 'VcColumnView',
			'params' => array(
				array(
					'type' => 'colorpicker',
					'class' => '',
					'heading' => esc_html__('Background Color', 'kudos'),
					'param_name' => 'background_color',
					'value' => '',
					'description' => ''
				),
				array(
					'type' => 'dropdown',
					'class' => '',
					'heading' => esc_html__('Columns', 'kudos'),
					'admin_label' => true,
					'param_name' => 'number_of_columns',
					'value' => array(
						esc_html__('1 Column', 'kudos')      => 'one-column',
						esc_html__('2 Columns', 'kudos')    	=> 'two-columns',
						esc_html__('3 Columns', 'kudos')     => 'three-columns',
						esc_html__('4 Columns', 'kudos')     => 'four-columns',
						esc_html__('5 Columns', 'kudos')     => 'five-columns',
						esc_html__('6 Columns', 'kudos')     => 'six-columns'
					),
					'description' => ''
				),
				array(
					'type' => 'checkbox',
					'class' => '',
					'heading' => esc_html__('Items Float Left', 'kudos'),
					'param_name' => 'items_float_left',
					'value' => array('Make Items Float Left?' => 'yes'),
					'description' => ''
				),
				array(
					'type' => 'dropdown',
					'class' => '',
					'group' => esc_html__('Width & Responsiveness', 'kudos'),
					'heading' => esc_html__('Switch to One Column', 'kudos'),
					'param_name' => 'switch_to_one_column',
					'value' => array(
						esc_html__('Default', 'kudos')    		=> '',
						esc_html__('Below 1280px', 'kudos') 		=> '1280',
						esc_html__('Below 1024px', 'kudos')    	=> '1024',
						esc_html__('Below 768px', 'kudos')     	=> '768',
						esc_html__('Below 600px', 'kudos')    	=> '600',
						esc_html__('Below 480px', 'kudos')    	=> '480',
						esc_html__('Never', 'kudos')    			=> 'never'
					),
					'description' => esc_html__('Choose on which stage item will be in one column', 'kudos')
				),
				array(
					'type' => 'dropdown',
					'class' => '',
					'group' => esc_html__('Width & Responsiveness', 'kudos'),
					'heading' => esc_html__('Choose Alignment In Responsive Mode', 'kudos'),
					'param_name' => 'alignment_one_column',
					'value' => array(
						esc_html__('Default', 'kudos')    	=> '',
						esc_html__('Left', 'kudos') 			=> 'left',
						esc_html__('Center', 'kudos')    	=> 'center',
						esc_html__('Right', 'kudos')     	=> 'right'
					),
					'description' => esc_html__('Alignment When Items are in One Column', 'kudos')
				)
			)
		));
	}

	public function render($atts, $content = null) {
	
		$args = array(
			'number_of_columns' 		=> '',
			'switch_to_one_column'		=> '',
			'alignment_one_column' 		=> '',
			'items_float_left' 			=> '',
			'background_color' 			=> ''
		);
		$params = shortcode_atts($args, $atts);
		extract($params);

		$html						= '';

		$elements_holder_classes = array();
		$elements_holder_classes[] = 'qodef-elements-holder';
		$elements_holder_style = '';

		if($number_of_columns != ''){
			$elements_holder_classes[] .= 'qodef-'.$number_of_columns ;
		}

		if($switch_to_one_column != ''){
			$elements_holder_classes[] = 'qodef-responsive-mode-' . $switch_to_one_column ;
		} else {
			$elements_holder_classes[] = 'qodef-responsive-mode-768' ;
		}

		if($alignment_one_column != ''){
			$elements_holder_classes[] = 'qodef-one-column-alignment-' . $alignment_one_column ;
		}

		if($items_float_left !== ''){
			$elements_holder_classes[] = 'qodef-elements-items-float';
		}

		if($background_color != ''){
			$elements_holder_style .= 'background-color:'. $background_color . ';';
		}

		$elements_holder_class = implode(' ', $elements_holder_classes);

		$html .= '<div ' . kudos_qodef_get_class_attribute($elements_holder_class) . ' ' . kudos_qodef_get_inline_attr($elements_holder_style, 'style'). '>';
			$html .= do_shortcode($content);
		$html .= '</div>';

		return $html;

	}

}
