<?php
namespace KudosQodef\Modules\Shortcodes\ImageWithText;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;

class ImageWithText implements ShortcodeInterface{

	private $base;

	/**
	 * ImageWithText constructor.
	 */
	public function __construct() {
		$this->base = 'qodef_image_with_text';

		add_action('vc_before_init', array($this, 'vcMap'));
	}

	/**
	 * Returns base for shortcode
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}

	/**
	 * Maps shortcode to Visual Composer. Hooked on vc_before_init
	 *
	 * @see qode_core_get_carousel_slider_array_vc()
	 */
	public function vcMap() {

		vc_map(array(
			'name'                      => esc_html__('Select Image With Text', 'kudos'),
			'base'                      => $this->getBase(),
			'category' 					=> 'by SELECT',
			'icon'                      => 'icon-wpb-image-with-text extended-custom-icon',
			'allowed_container_element' => 'vc_row',
			'params'                    => array(
				array(
					'type'			=> 'attach_image',
					'heading'		=> esc_html__('Image', 'kudos'),
					'param_name'	=> 'image',
					'description'	=> ''
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__('Title', 'kudos'),
					'admin_label' => true,
					'param_name' => 'image_with_text_title'
				),
				array(
				'type' => 'dropdown',
				'heading' => esc_html__('Title Tag', 'kudos'),
				'param_name' => 'image_with_text_title_tag',
				'value' => array(
					'' => '',
					esc_html__('h2', 'kudos') => 'h2',
					esc_html__('h3', 'kudos') => 'h3',
					esc_html__('h4', 'kudos') => 'h4',
					esc_html__('h5', 'kudos') => 'h5',
					esc_html__('h6', 'kudos') => 'h6',
					),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__('Subtitle', 'kudos'),
					'admin_label' => true,
					'param_name' => 'image_with_text_subtitle'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__('Link', 'kudos'),
					'admin_label' => true,
					'param_name' => 'image_with_text_link'
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__('Link Target', 'kudos'),
					'admin_label' => true,
					'param_name' => 'image_with_text_link_target',
					'value' => array(
						'' => '',
						esc_html__('Self', 'kudos') => '_self',
						esc_html__('Blank', 'kudos') => '_blank'
					),
				)
			)
		));

	}

	/**
	 * Renders shortcodes HTML
	 *
	 * @param $atts array of shortcode params
	 * @param $content string shortcode content
	 * @return string
	 */
	public function render($atts, $content = null) {

		$args = array(
			'image' => '',
			'image_with_text_title' => '',
			'image_with_text_title_tag' => 'h5',
			'image_with_text_subtitle' => '',
			'image_with_text_link' => '',
			'image_with_text_link_target' => ''
		);

		$params = shortcode_atts($args, $atts);

		$html = kudos_qodef_get_shortcode_module_template_part('templates/image-with-text', 'image-with-text', '', $params);

		return $html;

	}

}