<?php
namespace KudosQodef\Modules\Shortcodes\ParallaxSection;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;

class ParallaxSection implements ShortcodeInterface{
	private $base;

	function __construct() {
		$this->base = 'qodef_parallax_section';
		add_action('vc_before_init', array($this, 'vcMap'));
	}
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if(function_exists('vc_map')){
			vc_map( 
				array(
					'name' => esc_html__('Select Parallax Section', 'kudos'),
					'base' => $this->base,
					'as_child' => array('only' => 'qodef_parallax_sections'),
					'content_element' => true,
					'category' => 'by SELECT',
					'icon' => 'icon-wpb-parallax-section extended-custom-icon',
					'show_settings_on_create' => true,
					'params' => array(
						array(
							'type' => 'dropdown',
							'class' => '',
							'heading' => esc_html__('Parallax Section Type', 'kudos'),
							'param_name' => 'parallax_section_type',
							'value' => array(
								esc_html__('Basic', 'kudos')    	=> 'parallax-section-basic'
							),
							'save_always' => true,
							'description' => ''
						),
						array(
							'type' => 'dropdown',
							'class' => '',
							'heading' => esc_html__('Parallax Layout', 'kudos'),
							'param_name' => 'parallax_layout',
							'value' => array(
								esc_html__('Main Image on the Left', 'kudos')    	=> 'main_image_left',
								esc_html__('Main Image on the Right', 'kudos')     => 'main_image_right',
							),
							'save_always' => true,
							'description' => esc_html__('Choose between the two predefined layouts.', 'kudos')
						),
						array(
							'type' => 'attach_image',
							'class' => '',
							'heading' => esc_html__('Main Image', 'kudos'),
							'param_name' => 'main_image',
							'value' => '',
							'description' => esc_html__('Set the main parallax image.', 'kudos'),
						    'dependency' => array('element' => 'parallax_section_type', 'value' => 'parallax-section-basic')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Main Image Link', 'kudos'),
							'param_name' => 'main_image_link',
							'value' => '',
							'description' => esc_html__('Set an external URL to link to.', 'kudos'),
						    'dependency' => array('element' => 'main_image', 'not_empty' => true)
						),
						array(
	                        'type'        => 'dropdown',
	                        'heading'     => esc_html__('Main Image Link Target', 'kudos'),
	                        'param_name'  => 'main_image_link_target',
	                        'value'       => array(
	                            esc_html__('Same Window', 'kudos')  => '_self',
	                            esc_html__('New Window', 'kudos') => '_blank'
	                        ),
	                        'save_always' => true,
						    'dependency' => array('element' => 'main_image_link', 'not_empty' => true)
	                    ),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Main Image Y start offset', 'kudos'),
							'param_name' => 'main_image_y_start_offset',
							'value' => '0px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel start offset for Main Image', 'kudos'),
						    'dependency' => array('element' => 'main_image', 'not_empty' => true),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Main Image Y end offset', 'kudos'),
							'param_name' => 'main_image_y_end_offset',
							'value' => '-350px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel end offset for Main Image', 'kudos'),
						    'dependency' => array('element' => 'main_image', 'not_empty' => true),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'attach_image',
							'class' => '',
							'heading' => esc_html__('Side Image', 'kudos'),
							'param_name' => 'side_image',
							'value' => '',
							'description' => esc_html__('Set the side parallax image.', 'kudos'),
						    'dependency' => array('element' => 'parallax_section_type', 'value' => 'parallax-section-basic')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Side Image Link', 'kudos'),
							'param_name' => 'side_image_link',
							'value' => '',
							'description' => esc_html__('Set an external URL to link to.', 'kudos'),
						    'dependency' => array('element' => 'side_image', 'not_empty' => true)
						),
						array(
	                        'type'        => 'dropdown',
	                        'heading'     => esc_html__('Side Image Link Target', 'kudos'),
	                        'param_name'  => 'side_image_link_target',
	                        'value'       => array(
	                            esc_html__('Same Window', 'kudos')  => '_self',
	                            esc_html__('New Window', 'kudos') => '_blank'
	                        ),
	                        'save_always' => true,
						    'dependency' => array('element' => 'side_image_link', 'not_empty' => true)
	                    ),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Side Image Y start offset', 'kudos'),
							'param_name' => 'side_image_y_start_offset',
							'value' => '0px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel start offset for Side Image', 'kudos'),
						    'dependency' => array('element' => 'side_image', 'not_empty' => true),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Side Image Y end offset', 'kudos'),
							'param_name' => 'side_image_y_end_offset',
							'value' => '-350px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel end offset for Side Image', 'kudos'),
						    'dependency' => array('element' => 'side_image', 'not_empty' => true),
							'group' => esc_html__('Advanced Options', 'kudos')
						),

						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 1 Heading', 'kudos'),
							'param_name' => 'heading',
							'value' => '',
							'description' => ''
						),
						array(
							'type' => 'textarea',
							'class' => '',
							'heading' => esc_html__('Text Area 1 Excerpt', 'kudos'),
							'param_name' => 'excerpt',
							'value' => '',
							'description' => '',
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 1 Y start offset', 'kudos'),
							'param_name' => 'text_area_y_start_offset',
							'value' => '0px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel start offset for Text Area', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 1 Y end offset', 'kudos'),
							'param_name' => 'text_area_y_end_offset',
							'value' => '-250px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel end offset for Text Area', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 1 Background Number', 'kudos'),
							'param_name' => 'number',
							'value' => '',
							'description' => ''
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Background Number 1 Y start offset', 'kudos'),
							'param_name' => 'number_y_start_offset',
							'value' => '0px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel start offset for Text Area  Background Number', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Background Number 1 Y end offset', 'kudos'),
							'param_name' => 'number_y_end_offset',
							'value' => '-100px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel end offset for Text Area Background Number', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 2 Heading', 'kudos'),
							'param_name' => 'heading2',
							'value' => '',
							'description' => ''
						),
						array(
							'type' => 'textarea',
							'class' => '',
							'heading' => esc_html__('Text Area 2 Excerpt', 'kudos'),
							'param_name' => 'excerpt2',
							'value' => '',
							'description' => '',
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 2 Y start offset', 'kudos'),
							'param_name' => 'text_area_y_start_offset2',
							'value' => '0px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel start offset for Text Area 2', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 2 Y end offset', 'kudos'),
							'param_name' => 'text_area_y_end_offset2',
							'value' => '-250px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel end offset for Text area 2', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 2 Background Number', 'kudos'),
							'param_name' => 'number2',
							'value' => '',
							'description' => ''
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Background Number 2 Y start offset', 'kudos'),
							'param_name' => 'number2_y_start_offset',
							'value' => '0px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel start offset for Text Area 2 Background Number', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Background Number 2 Y end offset', 'kudos'),
							'param_name' => 'number2_y_end_offset',
							'value' => '-100px',
							'save_always' => true,
							'description' => esc_html__('Enter the Y-axis pixel end offset for Text Area 2 Background Number', 'kudos'),
							'group' => esc_html__('Advanced Options', 'kudos')
						),

						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Height', 'kudos'),
							'param_name' => 'height',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Top Margin', 'kudos'),
							'param_name' => 'top_margin',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Bottom Margin', 'kudos'),
							'param_name' => 'bottom_margin',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 1 Padding', 'kudos'),
							'param_name' => 'text_area1_padding',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 1 Number Background Padding', 'kudos'),
							'param_name' => 'text_area1_number_padding',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 2 Padding', 'kudos'),
							'param_name' => 'text_area2_padding',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'textfield',
							'class' => '',
							'heading' => esc_html__('Text Area 2 Number Background Padding', 'kudos'),
							'param_name' => 'text_area2_number_padding',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'colorpicker',
							'class' => '',
							'heading' => esc_html__('Number 1 Color', 'kudos'),
							'param_name' => 'number1_color',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						),
						array(
							'type' => 'colorpicker',
							'class' => '',
							'heading' => esc_html__('Number 2 Color', 'kudos'),
							'param_name' => 'number2_color',
							'value' => '',
							'description' => '',
							'group' => esc_html__('Layout Options', 'kudos')
						)
					)
				)
			);			
		}
	}

	public function render($atts, $content = null) {
		$args = array(
			'parallax_section_type' => '',
			'parallax_layout' => '',
			'main_image' => '',
			'main_image_link' => '',
			'main_image_link_target' => '_self',
			'main_image_y_start_offset' => '',
			'main_image_y_end_offset' => '',
			'side_image' => '',
			'side_image_link' => '',
			'side_image_link_target' => '_self',
			'side_image_y_start_offset' => '',
			'side_image_y_end_offset' => '',
			'excerpt' => '',
			'heading' => '',
			'number' => '',
			'number_y_start_offset' => '',
			'number_y_end_offset' => '',
			'text_area_y_start_offset' => '',
			'text_area_y_end_offset' => '',
			'text_area1_padding' => '',
			'text_area2_padding' => '',
			'text_area1_number_padding' => '',
			'text_area2_number_padding' => '',
			'excerpt2' => '',
			'heading2' => '',
			'text_area_y_start_offset2' => '',
			'text_area_y_end_offset2' => '',
			'height' => '',
			'number2' => '',
			'number2_y_start_offset' => '',
			'number2_y_end_offset' => '',
			'top_margin' => '',
			'bottom_margin' => '',
			'number1_color' => '',
			'number2_color' => ''
		);
		
		$params = shortcode_atts($args, $atts);
		extract($params);
		$params['content']= $content;

		//images
		$params['main_image_src'] = '';
		if (is_numeric($main_image)) {
		    $params['main_image_src'] = wp_get_attachment_url($main_image);
		} else {
		    $params['main_image_src'] = $main_image;
		}

		$params['side_image_src'] = '';
		if (is_numeric($side_image)) {
		    $params['side_image_src'] = wp_get_attachment_url($side_image);
		} else {
		    $params['side_image_src'] = $side_image;
		}

		$params['number1_style'] = $this->getNumber1Style($params);
		$params['number2_style'] = $this->getNumber2Style($params);
		$params['text_area1_padding'] = $this->getTextArea1Padding($params);
		$params['text_area2_padding'] = $this->getTextArea2Padding($params);
		$params['text_area1_number_padding'] = $this->getTextArea1NumberPadding($params);
		$params['text_area2_number_padding'] = $this->getTextArea2NumberPadding($params);
		$params['parallax_section_style'] = $this->getParallaxSectionStyle($params);
		$params['parallax_section_class'] = $this->getParallaxSectionClass($params);
		$params['offsets'] = $this->getBasicParallaxSectionTypeOffsets($params);

		$html = kudos_qodef_get_shortcode_module_template_part('templates/' . $params['parallax_section_type'], 'parallax-sections', '', $params);

		return $html;
	}


	/**
	 * Return Parallax Section style
	 *
	 * @param $params
	 * @return array
	 */
	private function getParallaxSectionStyle($params) {

		$parallax_section_style = array();

		if ($params['height'] !== '') {
			$parallax_section_style[] = 'height: ' . kudos_qodef_filter_px($params['height']) . 'px';
		}

		if ($params['top_margin'] !== '') {
			$parallax_section_style[] = 'margin-top: ' . kudos_qodef_filter_px($params['top_margin']);
		}

		if ($params['bottom_margin'] !== '') {
			$parallax_section_style[] = 'margin-bottom: ' . kudos_qodef_filter_px($params['bottom_margin']);
		}

		return implode(';', $parallax_section_style);

	}

	/**
	 * Return Parallax Number 1 style
	 *
	 * @param $params
	 * @return array
	 */
	private function getNumber1Style($params) {

		$number1_style ='';

		if ($params['number1_color'] !== '') {
			$number1_style = 'color: ' . $params['number1_color'];
		}

		return $number1_style;
	}

	/**
	 * Return Parallax Number 2 style
	 *
	 * @param $params
	 * @return array
	 */
	private function getNumber2Style($params) {

		$number2_style ='';

		if ($params['number2_color'] !== '') {
			$number2_style = 'color: ' . $params['number2_color'];
		}

		return $number2_style;
	}

	/**
	 * Return Text Area 1 Padding
	 *
	 * @param $params
	 * @return array
	 */
	private function getTextArea1Padding($params) {

		$text_area1_padding ='';

		if ($params['text_area1_padding'] !== '') {
			$text_area1_padding = 'padding: ' . $params['text_area1_padding'];
		}

		return $text_area1_padding;
	}

	/**
	 * Return Text Area 2 Padding
	 *
	 * @param $params
	 * @return array
	 */
	private function getTextArea2Padding($params) {

		$text_area2_padding ='';

		if ($params['text_area2_padding'] !== '') {
			$text_area2_padding = 'padding: ' . $params['text_area2_padding'];
		}

		return $text_area2_padding;
	}


	/**
	 * Return Text Area 1 Number Padding
	 *
	 * @param $params
	 * @return array
	 */
	private function getTextArea1NumberPadding($params) {

		$text_area1_number_padding ='';

		if ($params['text_area1_number_padding'] !== '') {
			$text_area1_number_padding = 'padding: ' . $params['text_area1_number_padding'];
		}

		return $text_area1_number_padding;
	}

	/**
	 * Return Text Area 2 Number Padding
	 *
	 * @param $params
	 * @return array
	 */
	private function getTextArea2NumberPadding($params) {

		$text_area2_number_padding ='';

		if ($params['text_area2_number_padding'] !== '') {
			$text_area2_number_padding = 'padding: ' . $params['text_area2_number_padding'];
		}

		return $text_area2_number_padding;
	}


	/**
	 * Return Parallax Section classes
	 *
	 * @param $params
	 * @return array
	 */
	private function getParallaxSectionClass($params) {

		$parallax_section_class = array();

		if (($params['parallax_layout'] !== '') && ($params['parallax_section_type'] == 'parallax-section-basic')) {
			if ($params['parallax_layout'] == 'main_image_left') {
				$parallax_section_class[] = 'qodef-parallax-layout-1';
			} elseif ($params['parallax_layout'] == 'main_image_right') {
				$parallax_section_class[] = 'qodef-parallax-layout-2';
			}
		}

		if ($params['height'] !== '') {
			$parallax_section_class[] = 'qodef-section-height-set';
		}

		return implode(' ', $parallax_section_class);

	}


	/**
	 * Return Basic Parallax Section Type offsets
	 *
	 * @param $params
	 * @return array
	 */
	private function getBasicParallaxSectionTypeOffsets($params){

		$parallax_section_offsets = array();

		if ($params['main_image_y_start_offset'] !== '') {
			$parallax_section_offsets['main_image_y_start_offset'] = kudos_qodef_filter_px($params['main_image_y_start_offset']) . 'px';
		} else {
			$parallax_section_offsets['main_image_y_start_offset'] = '0px';
		}

		if ($params['main_image_y_end_offset'] !== '') {
			$parallax_section_offsets['main_image_y_end_offset'] = kudos_qodef_filter_px($params['main_image_y_end_offset']) . 'px';
		} else {
			$parallax_section_offsets['main_image_y_start_offset'] = '-350px';
		}

		if ($params['side_image_y_start_offset'] !== '') {
			$parallax_section_offsets['side_image_y_start_offset'] = kudos_qodef_filter_px($params['side_image_y_start_offset']) . 'px';
		} else {
			$parallax_section_offsets['side_image_y_start_offset'] = '0px';
		}

		if ($params['side_image_y_end_offset'] !== '') {
			$parallax_section_offsets['side_image_y_end_offset'] = kudos_qodef_filter_px($params['side_image_y_end_offset']) . 'px';
		} else {
			$parallax_section_offsets['side_image_y_start_offset'] = '-350px';
		}

		if ($params['text_area_y_start_offset'] !== '') {
			$parallax_section_offsets['text_area_y_start_offset'] = kudos_qodef_filter_px($params['text_area_y_start_offset']) . 'px';
		} else {
			$parallax_section_offsets['text_area_y_start_offset'] = '0px';
		}

		if ($params['text_area_y_end_offset'] !== '') {
			$parallax_section_offsets['text_area_y_end_offset'] = kudos_qodef_filter_px($params['text_area_y_end_offset']) . 'px';
		} else {
			$parallax_section_offsets['text_area_y_end_offset'] = '-250px';
		}


		if ($params['text_area_y_start_offset2'] !== '') {
			$parallax_section_offsets['text_area_y_start_offset2'] = kudos_qodef_filter_px($params['text_area_y_start_offset2']) . 'px';
		} else {
			$parallax_section_offsets['text_area_y_start_offset2'] = '0px';
		}

		if ($params['text_area_y_end_offset2'] !== '') {
			$parallax_section_offsets['text_area_y_end_offset2'] = kudos_qodef_filter_px($params['text_area_y_end_offset2']) . 'px';
		} else {
			$parallax_section_offsets['text_area_y_end_offset2'] = '-250px';
		}


		if ($params['number_y_start_offset'] !== '') {
			$parallax_section_offsets['number_y_start_offset'] = kudos_qodef_filter_px($params['number_y_start_offset']) . 'px';
		} else {
			$parallax_section_offsets['number_y_start_offset'] = '0px';
		}

		if ($params['number_y_end_offset'] !== '') {
			$parallax_section_offsets['number_y_end_offset'] = kudos_qodef_filter_px($params['number_y_end_offset']) . 'px';
		} else {
			$parallax_section_offsets['number_y_end_offset'] = '-100px';
		}


		if ($params['number2_y_start_offset'] !== '') {
			$parallax_section_offsets['number2_y_start_offset'] = kudos_qodef_filter_px($params['number2_y_start_offset']) . 'px';
		} else {
			$parallax_section_offsets['number2_y_start_offset'] = '0px';
		}

		if ($params['number2_y_end_offset'] !== '') {
			$parallax_section_offsets['number2_y_end_offset'] = kudos_qodef_filter_px($params['number2_y_end_offset']) . 'px';
		} else {
			$parallax_section_offsets['number2_y_end_offset'] = '-100px';
		}

		return $parallax_section_offsets;

	}
}
