<?php
namespace KudosQodef\Modules\Shortcodes\ShopMasonry;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;


/**
 * Class ShopMasonry that represents shop masonry shortcode
 * @package KudosQodef\Modules\Shortcodes\ShopMasonry
 */
class ShopMasonry implements ShortcodeInterface
{
    /**
     * @var string
     */
    private $base;

    /**
     * Sets base attribute and registers shortcode with Visual Composer
     */
    public function __construct()
    {
        $this->base = 'qodef_shop_masonry';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    /**
     * Returns base attribute
     * @return string
     */
    public function getBase()
    {
        return $this->base;
    }

    /**
     * Maps shortcode to Visual Composer
     */
    public function vcMap()
    {
        vc_map(array(
            'name' => esc_html__('Select Shop Masonry', 'kudos'),
            'base' => $this->base,
            'category' => 'by SELECT',
            'icon' => 'icon-wpb-product-list-masonry extended-custom-icon',
            'allowed_container_element' => 'vc_row',
            'params' => array(
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__('Number of Items', 'kudos'),
                    'param_name' => 'items_number',
                    'value' => '',
                    'admin_label' => true,
                    'description' => esc_html__('Leave empty for all.', 'kudos')
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Order By', 'kudos'),
                    'param_name' => 'order_by',
                    'value' => array(
                        esc_html__('ID', 'kudos') => 'id',
                        esc_html__('Date', 'kudos') => 'date',
                        esc_html__('Menu Order', 'kudos') => 'menu_order',
                        esc_html__('Title', 'kudos') => 'title'
                    ),
                    'save_always' => true,
                    'admin_label' => true
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Sort Order', 'kudos'),
                    'param_name' => 'sort_order',
                    'value' => array(
                        esc_html__('Ascending', 'kudos') => 'ASC',
                        esc_html__('Descending', 'kudos') => 'DESC'
                    ),
                    'save_always' => true,
                    'admin_label' => true
                ),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__('Title Tag', 'kudos'),
					'param_name' => 'title_tag',
					'value' => array(
						'' => '',
						esc_html__('h2', 'kudos') => 'h2',
						esc_html__('h3', 'kudos') => 'h3',
						esc_html__('h4', 'kudos') => 'h4',
						esc_html__('h5', 'kudos') => 'h5',
						esc_html__('h6', 'kudos') => 'h6'
					),
					'description' => ''
				),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Choose Sorting Taxonomy', 'kudos'),
                    'param_name' => 'taxonomy_to_display',
                    'value' => array(
                        esc_html__('Category', 'kudos') => 'category',
                        esc_html__('Tag', 'kudos') => 'tag',
                        esc_html__('Id', 'kudos') => 'id'
                    ),
                    'save_always' => true,
                    'admin_label' => true,
                    'description' => esc_html__('If you would like to display only certain products, this is where you can select the criteria by which you would like to choose which products to display.', 'kudos')
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__('Enter Taxonomy Values', 'kudos'),
                    'param_name' => 'taxonomy_values',
                    'value' => '',
                    'admin_label' => true,
                    'description' => esc_html__('Separate values (category slugs, tags, or post IDs) with a comma', 'kudos')
                )
            )
        ));
    }

    /**
     * Renders HTML for product list shortcode
     *
     * @param array $atts
     * @param null $content
     *
     * @return string
     */
    public function render($atts, $content = null){
        $default_atts = array(
            'items_number' => '-1',
            'order_by' => 'date',
            'sort_order' => 'desc',
            'taxonomy_to_display' => 'category',
            'taxonomy_values' => '',
            'title_tag' => 'h5',
			'display_categories' => 'yes'
        );

        $params = shortcode_atts($default_atts, $atts);

        $query_args = $this->getQueryArgs($params);

        global $woocommerce_loop;

        $products = new \WP_Query($query_args);

        $html = '';
        $html .= '<div class="qodef-product-list-holder">';
        $html .= '<div class="woocommerce qodef-shop-masonry">';
		$html .= '<div class="products qodef-products-simple qodef-shop-list-masonry">';
		$html .= '<div class="qodef-shop-list-masonry-grid-sizer"></div>';

        if ($products->have_posts()) :

            do_action('kudos_qodef_before_shop_masonry_simple', $params);

            while ($products->have_posts()) : $products->the_post();

                $post_classes = implode(' ', get_post_class() );
				$params['image_size_class'] = $this->getMasonrySize(get_the_ID());
				$params['thumb_size'] = $this->getImageSize(get_the_ID());

                $html .= '<div class="qodef-shop-product  ' . $params['image_size_class'] . ' ' . $post_classes . '">';
                $html .= kudos_qodef_get_shortcode_module_template_part('templates/masonry-simple', 'shop-masonry', '', $params);
                $html .= '</div>';

            endwhile;

        endif;

        woocommerce_reset_loop();
        wp_reset_postdata();


        $html .= '</div>';
        $html .= '</div>';
        $html .= '</div>';

        return $html;

    }


    /**
     * Creates an array of args for loop
     *
     * @param $params
     * @return array
     */
    private function getQueryArgs($params){

        $args = array(
            'post_type' => 'product',
            'post_status' => 'publish',
            'ignore_sticky_posts' => 1,
            'orderby' => $params['order_by'],
            'order' => $params['sort_order'],
            'posts_per_page' => $params['items_number'],
            'meta_query' => WC()->query->get_meta_query()
        );

        if ($params['taxonomy_to_display'] != '' && $params['taxonomy_to_display'] == 'category') {
            $args['product_cat'] = $params['taxonomy_values'];
        }

        if ($params['taxonomy_to_display'] != '' && $params['taxonomy_to_display'] == 'tag') {
            $args['product_tag'] = $params['taxonomy_values'];
        }

        if ($params['taxonomy_to_display'] != '' && $params['taxonomy_to_display'] == 'id') {
            $idArray = $params['taxonomy_values'];
            $ids = explode(',', $idArray);
            $args['post__in'] = $ids;
        }

        return $args;
    }

	/**
	 * Gets required class for masonry layout
	 *
	 * @param $id
	 * @return string
	 */
	private function getMasonrySize(){
		$masonry_size_class = '';

		$masonry_size = get_post_meta(get_the_ID(), 'shop_masonry_dimensions',true);
		switch($masonry_size):
			case 'default' :
				$masonry_size_class = 'qodef-default-masonry-item ';
				break;
			case 'large_width' :
				$masonry_size_class = 'qodef-large-width-masonry-item ';
				break;
			case 'large_height' :
				$masonry_size_class = 'qodef-large-height-masonry-item ';
				break;
			case 'large_width_height' :
				$masonry_size_class = 'qodef-large-width-height-masonry-item ';
				break;
		endswitch;

		return $masonry_size_class;
	}

	/**
	 * Gets required class for product thumb
	 *
	 * @param $id
	 * @return string
	 */
	private function getImageSize(){

		$thumb_size = '';

		$masonry_size = get_post_meta(get_the_ID(), 'shop_masonry_dimensions',true);

		switch($masonry_size):
			case 'default' :
				$thumb_size = 'kudos_qodef_square_alt';
				break;
			case 'large_width' :
				$thumb_size = 'kudos_qodef_large_width';
				break;
			case 'large_height' :
				$thumb_size = 'kudos_qodef_large_height';
				break;
			case 'large_width_height' :
				$thumb_size = 'kudos_qodef_large_width_height';
				break;
		endswitch;

		return $thumb_size;
	}

}

