<?php
namespace KudosQodef\Modules\Shortcodes\VerticalSplitSliderItem;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;

class VerticalSplitSliderItem implements ShortcodeInterface{
	private $base;

	function __construct() {
		$this->base = 'qodef_vertical_split_slider_item';
		add_action('vc_before_init', array($this, 'vcMap'));
	}
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if(function_exists('vc_map')){
			vc_map( 
				array(
					'name' => esc_html__('Select Vertical Split Slider Item', 'kudos'),
					'base' => $this->base,
                    'as_parent' => array('only' => 'vc_single_image, qodef_button, qodef_icon, qodef_icon_list_item, qodef_icon_with_text, qodef_list_ordered, qodef_progress_bar, qodef_separator, qodef_unordered_list, qodef_video_button, vc_empty_space, vc_column_text, qodef_custom_font, qodef_blockquote, qodef_clients, qodef_counter, qodef_image_with_text, qodef_interactive_banner, qodef_numbered_process, qodef_pie_chart, qodef_pie_chart_doughnut, qodef_pie_chart_pie, qodef_pie_chart_with_icon, qodef_team, qodef_video_button, contact-form-7'),
					'as_child' => array('only' => 'qodef_vertical_split_slider_left_panel, qodef_vertical_split_slider_right_panel'),
					'category' => 'by SELECT',
					'icon' => 'icon-wpb-vertical-split-slider-item extended-custom-icon',
					"js_view" => 'VcColumnView',
					'show_settings_on_create' => true,
					"params" => array(
						array(
							"type" => "colorpicker",
							"heading" => esc_html__('Background Color', 'kudos'),
							"param_name" => "background_color",
							"value" => "",
							"description" => ""
						),
						array(
							"type" => "attach_image",
							"heading" => esc_html__('Background Image', 'kudos'),
							"param_name" => "background_image",
							"value" => "",
							"description" => ""
						),
						array(
							"type" => "textfield",
							"heading" => esc_html__('Padding', 'kudos'),
							"param_name" => "item_padding",
							"value" => "",
							"description" => esc_html__('Please insert value for left/right padding (ex. 50% or 50px)', 'kudos')
						),
						array(
							"type" => "dropdown",
							"heading" => esc_html__('Content Aligment', 'kudos'),
							"param_name" => "content_alignment",
							"value" => array(
								esc_html__('left' , 'kudos')  	=> "left",
								esc_html__('center', 'kudos')      => "center",
								esc_html__('right', 'kudos')     => "right"
							),
							"description" => ""
						),
						array(
							"type" => "dropdown",
							"heading" => esc_html__('Header/Bullets Style', 'kudos'),
							"param_name" => "header_style",
							"value" => array(
								""	=>	"",
								esc_html__('Light', 'kudos')	=>	"qodef-light-header",
								esc_html__('Dark', 'kudos')	=>	"qodef-dark-header"
							),
							"description" => ""
						)

					)
				)
			);			
		}
	}

	public function render($atts, $content = null) {
		$args = array(
			"background_image" => "",
			"background_color" => "",
			"link" => "",
			"target" => "_self",
			"content_alignment" => "left",
			"item_padding" => "",
			"header_style" => ""
		);

		$params = shortcode_atts($args, $atts);
		extract($params);

		$params['vertical_split_slider_holder_item_style'] = $this->getVerticalSplitSliderHolderItemStyle($params);
		$params['vertical_split_slider_holder_item_class'] = $this->getVerticalSplitSliderHolderItemClass($params);

		$html 	= '';
		$html	.= '<div class="'.$params['vertical_split_slider_holder_item_class'].'" style="'.$params['vertical_split_slider_holder_item_style'].'" data-header-style="'.$params['header_style'].'">';
		$html   .= '<div class="qodef-vertical-split-slider-section">';
                $html   .= do_shortcode($content);
                $html   .= '</div>';
                $html   .= '</div>';

		return $html;

	}


	/**
	 * Return Elements Holder Item style
	 *
	 * @param $params
	 * @return array
	 */
	private function getVerticalSplitSliderHolderItemStyle($params) {

		$vertical_split_slider_holder_item_style = array();

		if ($params['background_color'] !== '') {
			$vertical_split_slider_holder_item_style[] = 'background-color: ' . $params['background_color'];
		}
		if ($params['background_image'] !== '') {
			$vertical_split_slider_holder_item_style[] = 'background-image: url(' . wp_get_attachment_url($params['background_image']) . ')';
		}
        if ($params['item_padding'] !== '') {
            if(kudos_qodef_string_ends_with($params['item_padding'], '%') || kudos_qodef_string_ends_with($params['item_padding'], 'px')) {
                $vertical_split_slider_holder_item_style[] = 'padding-left: ' . $params['item_padding'];
                $vertical_split_slider_holder_item_style[] = 'padding-right: ' . $params['item_padding'];
            }else{
                $vertical_split_slider_holder_item_style[] = 'padding-left: ' . $params['item_padding'] . 'px';
                $vertical_split_slider_holder_item_style[] = 'padding-right: ' . $params['item_padding'] . 'px';
            }
        }
		return implode(';', $vertical_split_slider_holder_item_style);

	}

	/**
	 * Return Elements Holder Item classes
	 *
	 * @param $params
	 * @return array
	 */
	private function getVerticalSplitSliderHolderItemClass($params) {

		$vertical_split_slider_holder_item_class = array();
		$vertical_split_slider_holder_item_class[] = 'qodef-vertical-split-slider-item ms-section';

			switch($params['content_alignment']) {
				case 'left':
					$vertical_split_slider_holder_item_class[] = 'qodef-vertical-split-slider-align-left';
					break;
				case 'center':
					$vertical_split_slider_holder_item_class[] = 'qodef-vertical-split-slider-align-center';
					break;
				case 'right':
					$vertical_split_slider_holder_item_class[] = 'qodef-vertical-split-slider-align-right';
					break;
				default:
					break;
			}

		return implode(' ', $vertical_split_slider_holder_item_class);

	}

}
